@@ -26,6 +26,7 @@
 #include <DApplication>
 
 #include <QProcessEnvironment>
+#include <QTimer>
 
 MainWidget::MainWidget(QWidget *parent)
     : DAbstractDialog(false, parent)
@@ -45,16 +46,14 @@ void MainWidget::setJsonData(const QString &data, int flag)
     m_mainView->setScene(m_scene);
 
     if (str_output == "zh_CN.UTF-8") {
-        m_mainView->resize(m_scene->sceneRect().width() + 88, m_scene->sceneRect().height() + 80);
+        m_mainView->resize(static_cast<int>(m_scene->sceneRect().width() + 88), static_cast<int>(m_scene->sceneRect().height() + 80));
         setFixedSize(m_mainView->size().width() + CONTENT_MARGINS * 2, m_mainView->size().height() + CONTENT_MARGINS * 2);
     }
 
     else {
-        m_mainView->resize(m_scene->sceneRect().width() + 44, m_scene->sceneRect().height() + 40);
+        m_mainView->resize(static_cast<int>(m_scene->sceneRect().width() + 44), static_cast<int>(m_scene->sceneRect().height() + 40));
         setFixedSize(m_mainView->size().width() + CONTENT_MARGINS * 2, m_mainView->size().height() + CONTENT_MARGINS * 2);
     }
-
-
 }
 
 void MainWidget::initUI()
@@ -68,7 +67,7 @@ void MainWidget::initUI()
     m_mainView = new QGraphicsView(this);
 
     m_mainView->setStyleSheet("background: transparent;");
-    m_mainView->setFrameShape(QFrame::NoFrame);
+    setWindowFlag(Qt::FramelessWindowHint);
     m_mainView->setObjectName("MainView");
     m_mainLayout->addWidget(m_mainView);
 
@@ -82,7 +81,7 @@ void MainWidget::initUI()
         DPlatformWindowHandle handle(this);
 
         handle.setBorderWidth(2);
-        handle.setBorderColor(QColor(255, 255, 255, 255 * 0.15));
+        handle.setBorderColor(QColor(255, 255, 255, static_cast<int>(255 * 0.15)));
     }
 }
 
@@ -92,14 +91,14 @@ void MainWidget::mousePressEvent(QMouseEvent *e)
     DAbstractDialog::mousePressEvent(e);
 }
 
-//void MainWidget::keyReleaseEvent(QKeyEvent *e)
-//{
-////    if (e->key() == Qt::Key_Control || e->key() == Qt::Key_Shift) {
-////        releaseKeyboard();
-////        DAbstractDialog::keyReleaseEvent(e);
-////        hide();
-////    }
-//}
+void MainWidget::keyReleaseEvent(QKeyEvent *e)
+{
+    if (e->key() == Qt::Key_Control || e->key() == Qt::Key_Shift) {
+        releaseKeyboard();
+        DAbstractDialog::keyReleaseEvent(e);
+        hide();
+    }
+}
 
 void MainWidget::focusInEvent(QFocusEvent *e)
 {
@@ -119,11 +118,21 @@ void MainWidget::showEvent(QShowEvent *e)
 
     setFocus(Qt::MouseFocusReason);
     grabKeyboard();
+
+    QTimer::singleShot(500, this, [this](){
+        if (DApplication::queryKeyboardModifiers() != (Qt::ShiftModifier | Qt::ControlModifier))
+            hide();
+    });
+}
+
+void MainWidget::hideEvent(QHideEvent *e)
+{
+    DAbstractDialog::hideEvent(e);
 }
 
 void MainWidget::paintEvent(QPaintEvent *e)
 {
     Q_UNUSED(e)
     QPainter pa(this);
-    pa.fillRect(rect(), QColor(0, 0, 0, 255 * 0.7));
+    pa.fillRect(rect(), QColor(0, 0, 0, static_cast<int>(255 * 0.7)));
 }
