@@ -43,18 +43,19 @@ class MainWidget : public DAbstractDialog
 {
     Q_OBJECT
 public:
-    MainWidget(QWidget *parent = 0);
+    MainWidget(QWidget *parent = nullptr);
 
     void setJsonData(const QString &data, int flag = 0);
 
 protected:
     void mousePressEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
-//    void keyReleaseEvent(QKeyEvent *e) Q_DECL_OVERRIDE;
+    void keyReleaseEvent(QKeyEvent *e) Q_DECL_OVERRIDE;
     void focusInEvent(QFocusEvent *e) Q_DECL_OVERRIDE;
     void keyPressEvent(QKeyEvent *e) Q_DECL_OVERRIDE;
 
 protected:
     void showEvent(QShowEvent *e) Q_DECL_OVERRIDE;
+    void hideEvent(QHideEvent *e) Q_DECL_OVERRIDE;
     void paintEvent(QPaintEvent *e) override;
 
 private:
